@@ -6,6 +6,7 @@ from aiohttp.client_exceptions import ClientResponseError
 from typing import Union, TypedDict
 
 from .exceptions import (
+    OwletCredentialsError,
     OwletAuthenticationError,
     OwletConnectionError,
     OwletDevicesError,
@@ -104,11 +105,11 @@ class OwletAPI:
         self.headers = {}
         self.devices = {}
 
-        self._api_url = REGION_INFO[self._region]["url_base"]
-
         if self._region not in ["europe", "world"]:
             raise OwletAuthenticationError("Supplied region not valid")
 
+        self._api_url = REGION_INFO[self._region]["url_base"]
+
         if self.session is None:
             self.session = aiohttp.ClientSession()
 
@@ -152,6 +153,10 @@ class OwletAPI:
                                 raise OwletEmailError("Invalid email")
                             case "EMAIL_NOT_FOUND":
                                 raise OwletEmailError("Email address not found")
+                            case "INVALID_LOGIN_CREDENTIALS":
+                                raise OwletCredentialsError(
+                                    "Invalid login credentials"
+                                )
                             case "TOO_MANY_ATTEMPTS_TRY_LATER":
                                 raise OwletAuthenticationError(
                                     "Too many incorrect attempts"
@@ -279,7 +284,7 @@ class OwletAPI:
 
                 if response.status != 200:
                     match response.status:
-                        case 401:
+                        case 400:
                             raise OwletAuthenticationError("Refresh token not valid")
                         case _:
                             raise OwletError("Generic refresh error, contact dev")
@@ -304,7 +309,7 @@ class OwletAPI:
         """
         if self._auth_token is None and self._refresh is None:
             if self._user is None or self._password is None:
-                return OwletAuthenticationError("Username or password not supplied")
+                raise OwletAuthenticationError("Username or password not supplied")
 
             await self.password_verification()
 
