@@ -3,7 +3,7 @@ from logging import Logger
 import json
 import datetime
 from .api import OwletAPI, TokenDict
-from .const import PROPERTIES, VITALS
+from .const import PROPERTIES, VITALS_3, VITALS_2
 from typing import Union, TypedDict
 
 logger: Logger = logging.getLogger(__package__)
@@ -14,6 +14,7 @@ class PropertiesDict(TypedDict):
     properties: dict
     tokens: Union[None, TokenDict]
 
+
 class Sock:
     """
     Class representing a Owlet sock device
@@ -82,6 +83,7 @@ class Sock:
         self._device_type = data["device_type"]
         self._manuf_model = data["manuf_model"]
         self._version = None
+        self._revision = None
 
         self._raw_properties = {}
         self._properties = {}
@@ -142,6 +144,10 @@ class Sock:
     def raw_properties(self) -> dict:
         return self._raw_properties
 
+    @property
+    def revision(self) -> int:
+        return self._revision
+
     def get_property(self, property: str) -> str:
         """
         Returns the specific property based on the property argument passed in
@@ -171,28 +177,53 @@ class Sock:
         properties = {}
 
         for type, properties_tmp in PROPERTIES.items():
-            properties = {
-                key: type(self._raw_properties[property]["value"])
-                for key, property in properties_tmp.items()
-            }
+            for key, property in properties_tmp.items():
+                try:
+                    properties[key] = type(self._raw_properties[property]["value"])
+                except KeyError:
+                    pass
 
         if self._version == 3:
             vitals = json.loads(self._raw_properties["REAL_TIME_VITALS"]["value"])
 
-            for type, vitals_tmp in VITALS.items():
-                for key, property in vitals_tmp.items():
-                    match key:
+            for type, vitals_list in VITALS_3.items():
+                for vital_desc, vital_key in vitals_list.items():
+                    match vital_desc:
                         case "base_station_on":
-                            properties[key] = bool(vitals["bso"]) or bool(vitals["chg"])
+                            try:
+                                properties[vital_desc] = bool(vitals["bso"]) or bool(
+                                    vitals["chg"]
+                                )
+                            except KeyError:
+                                if "bso" in vitals:
+                                    properties[vital_desc] = bool(vitals["bso"])
+                                else:
+                                    pass
                         case "last_updated":
-                            properties[key] = datetime.datetime.strptime(
-                                self._raw_properties["REAL_TIME_VITALS"][
-                                    "data_updated_at"
-                                ],
-                                "%Y-%m-%dT%H:%M:%SZ",
-                            ).strftime("%Y/%m/%d %H:%M:%S")
+                            try:
+                                properties[vital_desc] = datetime.datetime.strptime(
+                                    self._raw_properties["REAL_TIME_VITALS"][
+                                        "data_updated_at"
+                                    ],
+                                    "%Y-%m-%dT%H:%M:%SZ",
+                                ).strftime("%Y/%m/%d %H:%M:%S")
+                            except KeyError:
+                                pass
                         case _:
-                            properties[key] = type(vitals[property])
+                            try:
+                                properties[vital_desc] = type(vitals[vital_key])
+                            except KeyError:
+                                pass
+
+        if self._version == 2:
+            for type, vitals_list in VITALS_2.items():
+                for vital_desc, vital_key in vitals_list.items():
+                    try:
+                        properties[vital_desc] = type(
+                            self._raw_properties[vital_key]["value"]
+                        )
+                    except KeyError:
+                        pass
 
         return properties
 
@@ -204,6 +235,10 @@ class Sock:
             version = 2
         self._version = version
 
+    async def _check_revision(self) -> None:
+        revision_json = json.loads(self._raw_properties["oem_sock_version"]["value"])
+        self._revision = revision_json["rev"]
+
     async def update_properties(
         self,
     ) -> PropertiesDict:
@@ -221,6 +256,8 @@ class Sock:
         self._raw_properties = properties["response"]
         if self._version is None:
             await self._check_version()
+        if self._revision is None and self._version == 3:
+            await self._check_revision()
         self._properties = await self.normalise_properties()
 
         return {
